/******************************************************************************
 *                                     __                                     *
 *                              <-----/@@\----->                              *
 *                             <-< <  \\//  > >->                             *
 *                               <-<-\ __ /->->                               *
 *                               Data /  \ Crow                               *
 *                                   ^    ^                                   *
 *                       (c) 2003 The Data Crow team                          *
 *                              info@datacrow.net                             *
 *                                                                            *
 *                                                                            *
 *       This library is free software; you can redistribute it and/or        *
 *        modify it under the terms of the GNU Lesser General Public          *
 *       License as published by the Free Software Foundation; either         *
 *     version 2.1 of the License, or (at your option) any later version.     *
 *                                                                            *
 *      This library is distributed in the hope that it will be useful,       *
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU       *
 *           Lesser General Public License for more details.                  *
 *                                                                            *
 *     You should have received a copy of the GNU Lesser General Public       *
 *    License along with this library; if not, write to the Free Software     *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA   *
 *                                                                            *
 ******************************************************************************/

package net.sf.dc.console;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.Font;
import java.awt.GridBagConstraints;
import java.awt.Insets;
import java.io.File;

import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JWindow;

import net.sf.dc.console.components.ComponentFactory;
import net.sf.dc.console.components.Layout;
import net.sf.dc.console.components.PictureField;
import net.sf.dc.console.dialogs.MessageBox;
import net.sf.dc.resources.DCLabels;
import net.sf.ext.util.Resources;
import net.sf.ext.util.Utilities;


public final class SplashScreen extends JWindow {

    private final JLabel lblStatus = ComponentFactory.getLabel("");

    public SplashScreen() {
        buildPanel();
    }
   
    public void setStatusMsg(String message) {
    	lblStatus.setText(message);
    }
    
    /**
     * Show the splash screen to the end user.
     * 
     * Once this method returns, the splash screen is realized, which means that
     * almost all work on the splash screen should proceed through the event
     * dispatch thread. In particular, any call to dispose for the splash screen
     * must be performed in the event dispatch thread.
     */
	public void splash() {
		setVisible(true);
	}

    private void buildPanel() {
        JPanel panelPicture = new JPanel(false);
        JPanel panelStatus = new JPanel(false);

        //**********************************************************
        //Logo panel
        //**********************************************************
        panelPicture.setLayout(Layout.getGBL());
        PictureField picField = ComponentFactory.getPictureField(false);
        try {
            File file = new File("./icons_system/logo.jpg");
            picField.setValue(file.toURL());
        } catch (Exception exp) {
            new MessageBox(exp.toString(), MessageBox._ERROR);
        }

        panelPicture.add(picField,  Layout.getGBC( 0, 0, 1, 1, 1.0, 1.0
        		                   ,GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH,
								    new Insets(0, 0, 0, 0), 0, 0));

        //**********************************************************
        //Status panel
        //**********************************************************
        panelStatus.setLayout(Layout.getGBL());
        lblStatus.setPreferredSize(new Dimension(500, 22));
        lblStatus.setText(Resources.getText(DCLabels.lblVersion));
        lblStatus.setBackground(Color.WHITE);
        lblStatus.setHorizontalAlignment(JLabel.CENTER);
        lblStatus.setFont(new Font("Luicida Console", Font.BOLD, 11));
        
        panelStatus.setBackground(Color.WHITE);

        panelStatus.add(lblStatus, Layout.getGBC( 0, 0, 1, 1, 0.0, 1.0
                                   ,GridBagConstraints.NORTHWEST, GridBagConstraints.HORIZONTAL,
                                    new Insets( 0, 0, 0, 0), 0, 0));

        //**********************************************************
        //Main panel
        //**********************************************************
        getContentPane().setLayout(Layout.getGBL());

        // Build the panel
        this.getContentPane().add(   panelPicture,  Layout.getGBC( 0, 0, 1, 1, 50.0, 50.0
                                                   ,GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH,
                                                    new Insets( 0, 0, 0, 0), 0, 0));
        this.getContentPane().add(   panelStatus,   Layout.getGBC( 0, 1, 1, 1, 1.0, 1.0
        		                                   ,GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH,
												    new Insets( 0, 0, 0, 0), 0, 0));
        pack();

        Dimension location = Utilities.getCenteredWindowLocation(getSize());
        setLocation(location.width, location.height);     
    }
}

