/******************************************************************************
 *                                     __                                     *
 *                              <-----/@@\----->                              *
 *                             <-< <  \\//  > >->                             *
 *                               <-<-\ __ /->->                               *
 *                               Data /  \ Crow                               *
 *                                   ^    ^                                   *
 *                       (c) 2003 The Data Crow team                          *
 *                              info@datacrow.net                             *
 *                                                                            *
 *                                                                            *
 *       This library is free software; you can redistribute it and/or        *
 *        modify it under the terms of the GNU Lesser General Public          *
 *       License as published by the Free Software Foundation; either         *
 *     version 2.1 of the License, or (at your option) any later version.     *
 *                                                                            *
 *      This library is distributed in the hope that it will be useful,       *
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU       *
 *           Lesser General Public License for more details.                  *
 *                                                                            *
 *     You should have received a copy of the GNU Lesser General Public       *
 *    License along with this library; if not, write to the Free Software     *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA   *
 *                                                                            *
 ******************************************************************************/

package net.sf.dc.console.components;

import java.net.URL;
import java.util.Enumeration;
import java.util.Vector;

import javax.swing.table.DefaultTableModel;

import net.sf.dc.core.Repository;
import net.sf.dc.core.modules.DCModule;
import net.sf.ext.util.Utilities;

/**
 * Leaves room for own implementation in the table model when needed...
 * At this moment this class behaves exactly the same as the
 * DefaultTableModel.
 *
 * @author Robert Jan van der Waals
 * @since 1.4
 * @version 1.9
 */
public class DCTableModel extends DefaultTableModel {
    
    private DCModule module;
    public DCTableModel(DCModule module) {
        this.module = module;
    }
    
    public DCTableModel() {
        this.module = null;;
    }    
    
    /**
     * Creates a special value for displaying purposes only
     * @param column target column
     * @param o value for which a display value is created
     */
    private Object createDisplayValue(int column, Object o) {
        if (module != null && 
            module.getFieldDefinition(column).getValueType() == Repository.datatypes._OBJECT) {

            String s = o.toString();
            if (!s.endsWith("jpg") && s.length() > 20) {
            	URL cacheUrl = Utilities.createCachedImage(s);
                s = null;
            	if (cacheUrl != null) {
            		o = cacheUrl.getPath();
            	}
            }
        }
        return o;
    }
    
    /**
     * Implementation of setValueAt to create different display values for 
     * pictures and other special fields
     * @param o value to set
     * @param row the row number
     * @param column the column number
     */    
    public void setValueAt(Object o, int row, int column) {
        super.setValueAt(createDisplayValue(column, o), row, column);
    }
    
    /**
     * Implementation of addRow to create different display values for 
     * pictures and other special fields
     * @param data vector of rows to be added to the table
     */
    public void addRow(Vector data) {
        int i = 0;
        for (Enumeration enumerator = data.elements(); enumerator.hasMoreElements(); i++) {
            data.setElementAt(createDisplayValue(i, enumerator.nextElement()), i);
        }
        super.addRow(data);
    }
    
    /**
     * Implementation of addRow to create different display values for 
     * pictures and other special fields
     * @param data row to be added to the table
     */    
    public void addRow(Object[] data) {
       for (int i = 0; i < data.length; i++) {
       	    data[i] = createDisplayValue(i, data[i]);
       }
       super.addRow(data);
    }
}