package net.sf.dc.console.wizards;

import java.awt.GridBagConstraints;
import java.awt.Insets;

import net.sf.dc.console.AmazonSearchForm;
import net.sf.dc.console.InternetSearchForm;
import net.sf.dc.console.audiocd.ImportAudioCDDialog;
import net.sf.dc.console.components.Layout;
import net.sf.dc.console.movie.ImdbMovieSearchForm;
import net.sf.dc.core.modules.DCModule;
import net.sf.dc.core.objects.DCObject;
import net.sf.dc.resources.DCMessages;
import net.sf.ext.util.Resources;

public class InternetWizardPanel extends WizardPanel {
    
    InternetSearchForm internetSearchForm = null;
    private boolean autoSearch = true; 
    
    public InternetWizardPanel(DCModule module, DCObject dco) {
        build(module, dco);
    }    
    
    public DCObject apply() throws WizardException {
        DCObject result = internetSearchForm.getSelectedData();
        if (result == null) throw new WizardException("No item selected!");
        
        return result;
    }
    
    public String getHelpText() {
        return Resources.getText(DCMessages.msgInternetSearch);
    }
    
    public void setObject(DCObject dco) {
        internetSearchForm.setSearchString(dco.getValue(1).toString());
        if (autoSearch) {
            autoSearch = false;
            internetSearchForm.startSearch();
        } 
    }
    
    private void build(DCModule module, DCObject dco) {
        if (module.isAmazonUpdateAllowed()) {  
            internetSearchForm = new AmazonSearchForm(dco, 0);
        } else if (module.isImdbUpdateAllowed()) {
            internetSearchForm = new ImdbMovieSearchForm(dco, 0, 0);
        } else if (module.isFreedBUpdateAllowed()) {
            internetSearchForm = new ImportAudioCDDialog(this.getClass(), 0);
        } 

        if (internetSearchForm != null) {
            setLayout(Layout.getGBL());
            add(internetSearchForm.getSettingsPanel(), Layout.getGBC(0, 0, 1, 1, 1.0, 1.0
                           ,GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH,
                            new Insets(5, 5, 5, 5), 0, 0));
            add(internetSearchForm.getSearchPanel(),   Layout.getGBC(0, 1, 1, 1, 1.0, 1.0
                           ,GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH,
                            new Insets(5, 5, 5, 5), 0, 0));
            add(internetSearchForm.getResultPanel(),   Layout.getGBC(0, 2, 1, 1, 10.0, 10.0
                           ,GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH,
                            new Insets(5, 5, 5, 5), 0, 0));
        }
    }
}